Package: rsyslog-gnutls
Version: 8.16.0-1~bpo8+1

Hello,

I've noticed that connections to a remote loghost of ours where dropped with the following message :

rsyslogd-2078: unexpected GnuTLS error -50 in nsd_gtls.c:530: The request is invalid. [v8.16.0 try http://www.rsyslog.com/e/2078 ]


Quickly, I found out that the issue has already been reported to, and fixed by upstream :

https://github.com/rsyslog/rsyslog/issues/732


I've tested the provided patch, and it indeed fixed the issue for us.

Maybe this could be included to an upcoming bump ? :)


Regards.


--
Dejan
diff --git a/runtime/nsd_gtls.c b/runtime/nsd_gtls.c
index afc1e60..5e9c938 100644
--- a/runtime/nsd_gtls.c
+++ b/runtime/nsd_gtls.c
@@ -1592,8 +1592,9 @@ Rcv(nsd_t *pNsd, uchar *pBuf, ssize_t *pLenBuf)
 	*pLenBuf = iBytesCopy;
 
 finalize_it:
-	if (iRet != RS_RET_OK) {
-		/* in this case, we also need to free the receive buffer, if we
+	if (iRet != RS_RET_OK && 
+		iRet != RS_RET_RETRY) {
+		/* We need to free the receive buffer in error error case unless a retry is wanted. , if we
 		 * allocated one. -- rgerhards, 2008-12-03 -- moved here by alorbach, 2015-12-01
 		 */
 		*pLenBuf = 0;

Reply via email to